package com.muyu.marketing.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.model.ActivityTeamInfoAddModel;
import com.muyu.marketing.domain.model.ActivityTeamInfoEditModel;
import com.muyu.marketing.domain.model.ActivityTeamInfoUpdModel;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.util.Date;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "activity_team_info", autoResultMap = true)
public class ActivityTeamInfo extends BaseEntity {

  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private long id;
  /**
   * 拼团名称
   */
  private String name;
  /**
   * 商品ID
   */
  private long productId;
  /**
   * 商品活动图
   */
  private String productImage;
  /**
   * 活动简介
   */
  private String introduction;
  /**
   * 单位
   */
  private String unit;
  /**
   * 轮播图
   */
  private String imageList;
  /**
   * 活动结束时间
   */
  private Date endTime;
  /**
   * 活动排序
   */
  private long sort;
  /**
   * 活动详情
   */
  private String content;
  /**
   * 活动状态
   */
  private String status;
  /**
   * 策略类型
   */
  private String strategyType;
  /**
   * 策略ID
   */
  private long strategyId;

  /**
   * 公共添加模型，转换成添加对象
   * @param activityTeamInfoAddModel 添加模型
   * @return 添加对象
   */
  public static ActivityTeamInfo addModelBuild(ActivityTeamInfoAddModel activityTeamInfoAddModel){
    return ActivityTeamInfo.builder()
            .name(activityTeamInfoAddModel.getName())
            .productId(activityTeamInfoAddModel.getProductId())
            .productImage(activityTeamInfoAddModel.getProductImage())
            .introduction(activityTeamInfoAddModel.getIntroduction())
            .unit(activityTeamInfoAddModel.getUnit())
            .imageList(activityTeamInfoAddModel.getImageList())
            .endTime(activityTeamInfoAddModel.getEndTime())
            .sort(activityTeamInfoAddModel.getSort())
            .content(activityTeamInfoAddModel.getContent())
            .status(activityTeamInfoAddModel.getStatus())
            .strategyType(activityTeamInfoAddModel.getStrategyType())
            .strategyId(activityTeamInfoAddModel.getStrategyId())
            .build();
  }

  /**
   * 公共修改模型  转换成修改对象
   * @param activityTeamInfoEditModel
   */
  public static ActivityTeamInfo editBuild(ActivityTeamInfoEditModel activityTeamInfoEditModel) {
    return  ActivityTeamInfo.builder()
            .name(activityTeamInfoEditModel.getName())
            .unit(activityTeamInfoEditModel.getUnit())
            .status(activityTeamInfoEditModel.getStatus())
            .productId(activityTeamInfoEditModel.getProductId())
            .strategyType(activityTeamInfoEditModel.getStrategyType())
            .strategyId(activityTeamInfoEditModel.getStrategyId())
            .productImage(activityTeamInfoEditModel.getProductImage())
            .introduction(activityTeamInfoEditModel.getIntroduction())
            .imageList(activityTeamInfoEditModel.getImageList())
            .endTime(activityTeamInfoEditModel.getEndTime())
            .id(activityTeamInfoEditModel.getTeamId())
            .content(activityTeamInfoEditModel.getContent())
            .sort(activityTeamInfoEditModel.getSort())
            .build();
  }
  /**
   * 公共修改模型  转换成修改对象
   * @param activityTeamInfoUpdModel
   */
  public static ActivityTeamInfo infoBuildModel(ActivityTeamInfoUpdModel activityTeamInfoUpdModel) {
    return  ActivityTeamInfo.builder()
            .name(activityTeamInfoUpdModel.getName())
            .unit(activityTeamInfoUpdModel.getUnit())
            .status(activityTeamInfoUpdModel.getStatus())
            .productId(activityTeamInfoUpdModel.getProductId())
            .strategyType(activityTeamInfoUpdModel.getStrategyType())
            .strategyId(activityTeamInfoUpdModel.getStrategyId())
            .productImage(activityTeamInfoUpdModel.getProductImage())
            .introduction(activityTeamInfoUpdModel.getIntroduction())
            .imageList(activityTeamInfoUpdModel.getImageList())
            .endTime(activityTeamInfoUpdModel.getEndTime())
            .id(activityTeamInfoUpdModel.getId())
            .content(activityTeamInfoUpdModel.getContent())
            .sort(activityTeamInfoUpdModel.getSort())
            .build();
  }
}
