package com.muyu.group.team.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.marketing.domain.ActivityTeamProductSkuInfo;
import com.muyu.marketing.domain.model.*;
import com.muyu.marketing.domain.req.ActivityTeamSkuReq;

import java.util.Collection;
import java.util.List;

public interface ActivityTeamProductSkuInfoService extends IService<ActivityTeamProductSkuInfo> {

    public default List<ActivityTeamProductSkuInfo> getActivityTeamProductSkuInfoByTeamId(Long teamId){
        LambdaQueryWrapper<ActivityTeamProductSkuInfo> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ActivityTeamProductSkuInfo::getTeamId, teamId);
        return this.list(lambdaQueryWrapper);
    }
    /**
     * 通过团购活动ID获取团购中最优惠的价格
     * @param teamId 团购ID
     * @return 优惠价格
     */
    public TeamProductDiscountPriceModel getDiscountPrice(Long teamId);
    /**
     * 通过活动ID获取 剩余库存
     * @param teamId 活动ID
     * @return 库存
     */
    public TeamProductStockModel getStock(Long teamId);
    /**
     * 添加团购商品SKU
     * @param activityTeamProductSkuAddModelList 团购商品SKU添加模型集合
     */
    public void batchSave(List<ActivityTeamProductSkuAddModel> activityTeamProductSkuAddModelList);
    /**
     * 根据团购id查询商品详细信息
     */
    public List<ActivityTeamSkuInfoDetailModel> findByListSkuInfo(Long id);

    /**
     * 修改
     * @param activityTeamProductSkuEditModelList
     */
    void editSku(List<ActivityTeamProductSkuEditModel> activityTeamProductSkuEditModelList);
    /**
     * 团购商品sku修改
     */
    public void batchUpd(List<ActivityTeamProductSkuUpdModel>  activityTeamProductSkuUpdModelList);


    /**
     * 批量添加团购sku
     */
    public void batchAdd(Collection<ActivityTeamSkuAddModel> activityTeamSkuAddModelCollection );

    /**
     * 根据拼团活动id查找sku
     * @param id
     * @return
     */
    List<ActivityTeamProductSkuUpdModel> findByTeamId(long id);
    /**
     * 批量删除团购sku
     */
    void batchDel(Collection<ActivityTeamProductSkuUpdModel> subtract);

    /**
     * 根据活动id查询商品sku
     * @param id
     * @return
     */
    List<ActivityTeamSkuAddModel> activityTeamAdd(long id);
}
