package com.muyu.group.team.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.group.team.mapper.ActivityTeamInfoMapper;
import com.muyu.group.team.service.ActivityTeamInfoService;
import com.muyu.group.team.service.ActivityTeamOpenInfoService;
import com.muyu.group.team.service.ActivityTeamProductSkuInfoService;
import com.muyu.marketing.domain.ActivityTeamInfo;
import com.muyu.marketing.domain.model.*;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import java.util.Collection;
import java.util.List;


@Service
public class ActivityTeamInfoServiceImpl extends ServiceImpl<ActivityTeamInfoMapper, ActivityTeamInfo>
    implements ActivityTeamInfoService {

    @Autowired
    private ActivityTeamOpenInfoService activityTeamOpenInfoService;

    @Autowired
    private ActivityTeamProductSkuInfoService activityTeamProductSkuInfoService;

    @Override
    public TableDataInfo<ActivityTeamInfoListModel> query(ActivityTeamInfoListQueryModel activityTeamInfoListQueryModel) {

        LambdaQueryWrapper<ActivityTeamInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getKeyWord()), ActivityTeamInfo::getName, activityTeamInfoListQueryModel.getKeyWord());
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getStatus()), ActivityTeamInfo::getStatus, activityTeamInfoListQueryModel.getStatus());

        /*
         * Object<T> -> 创建对象的时候进行的占用
         * <T> Result<T> 以方法返回值为占用
         */
        Page<ActivityTeamInfo> activityTeamInfoPage = this.page(activityTeamInfoListQueryModel.buildPage(), queryWrapper);
        List<ActivityTeamInfo> activityTeamInfoList = activityTeamInfoPage.getRecords();
        List<ActivityTeamInfoListModel> activityTeamInfoListModels = activityTeamInfoList.stream()
                .map(activityTeamInfo -> ActivityTeamInfoListModel.infoBuild(activityTeamInfo,
                        (activityTeamInfoListModelBuilder) -> {
                            TeamProductDiscountPriceModel discountPrice = activityTeamProductSkuInfoService.getDiscountPrice(activityTeamInfo.getId());
                            TeamProductStockModel teamProductStockModel = activityTeamProductSkuInfoService.getStock(activityTeamInfo.getId());
                            Long teamOpenTypeNumber = activityTeamOpenInfoService.getTeamOpenTypeNumberByTeamId(activityTeamInfo.getId());
                            Long teamInTypeNumber = activityTeamOpenInfoService.getTeamInTypeNumberByTeamId(activityTeamInfo.getId());

                            return activityTeamInfoListModelBuilder
                                    .openTeamNumber(teamOpenTypeNumber)
                                    .addTeamNumber(teamInTypeNumber)
                                    .attendNumber(teamOpenTypeNumber + teamInTypeNumber)
                                    .teamPrice(discountPrice.getTeamPrice())
                                    .productPrice(discountPrice.getProductPrice())
                                    .teamStock(teamProductStockModel.getTeamStock())
                                    .remainStock(teamProductStockModel.getRemainStock())
                                    .build();
                        })).toList();
        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = new TableDataInfo<>();
        tableDataInfo.setTotal(activityTeamInfoPage.getTotal());
        tableDataInfo.setRows(activityTeamInfoListModels);
        return tableDataInfo;
    }

    /**
     * 通过添加模型，去进行商品拼团活动的操作
     *
     * @param activityTeamInfoAddModel 团购添加模型
     */
    @Override
    public void save(ActivityTeamInfoAddModel activityTeamInfoAddModel) {
        ActivityTeamInfo activityTeamInfo = ActivityTeamInfo.addModelBuild(activityTeamInfoAddModel);
        Assert.isTrue(this.save(activityTeamInfo), StringUtils.format("团购活动添加失败：[{}]", activityTeamInfoAddModel));
        List<ActivityTeamProductSkuAddModel> teamProductSkuAddModelList = activityTeamInfoAddModel.getActivityTeamProductSkuAddModelList();
        teamProductSkuAddModelList.forEach(activityTeamProductSkuAddModel -> activityTeamProductSkuAddModel.setTeamId(activityTeamInfo.getId()));
        this.activityTeamProductSkuInfoService.batchSave(teamProductSkuAddModelList);
    }
    /**
     * 根据团购活动id查询详情
     */
    @Override
    public ActivityTeamInfoDetailModel echo(Long id) {
        ActivityTeamInfo activityTeamInfo = this.getById(id);
        List<ActivityTeamSkuInfoDetailModel> infoServiceByListSkuInfo = activityTeamProductSkuInfoService.findByListSkuInfo(id);
        return ActivityTeamInfoDetailModel.skuInfoDetailBuild(activityTeamInfo,infoServiceByListSkuInfo);
    }

    /**
     * 通过修改模型，去进行商品拼团活动的操作
     * @param activityTeamInfoEditModel 修改模型
     */
    @Override
    public void edit(ActivityTeamInfoEditModel activityTeamInfoEditModel) {
        //修改拼团活动
        ActivityTeamInfo activityTeamInfo = ActivityTeamInfo.editBuild(activityTeamInfoEditModel);
        this.updateById(activityTeamInfo);
        List<ActivityTeamProductSkuEditModel> activityTeamProductSkuEditModelList = activityTeamInfoEditModel.getActivityTeamProductSkuEditModels();
        activityTeamProductSkuEditModelList.forEach(activityTeamProductSkuEditModel -> {
            activityTeamProductSkuEditModel.setTeamId(activityTeamInfo.getId());
            activityTeamProductSkuEditModel.setProductId(activityTeamInfo.getProductId());
        });
        activityTeamProductSkuInfoService.editSku(activityTeamProductSkuEditModelList);
    }
    /**
     * 通过修改模型 ，去进行商品拼团活动
     * @param activityTeamInfoUpdModel 商品拼团模型
     */
    @Override
    public void upd(ActivityTeamInfoUpdModel activityTeamInfoUpdModel) {
        if ("N".equals(activityTeamInfoUpdModel.getStatus())){
            this.updateById(ActivityTeamInfo.infoBuildModel(activityTeamInfoUpdModel));
            List<ActivityTeamProductSkuUpdModel> activityTeamSkuInfoDetailModel= activityTeamProductSkuInfoService.findByTeamId(activityTeamInfoUpdModel.getId());
            ActivityTeamSkuModel activityTeamSkuModel = activityTeamInfoUpdModel.getActivityTeamSkuModel();
            List<ActivityTeamProductSkuUpdModel> activityTeamProductSkuUpdModelList = activityTeamSkuModel.getActivityTeamProductSkuUpdModelList();
            //删除
            Collection<ActivityTeamProductSkuUpdModel> subtract = CollectionUtils.subtract(activityTeamSkuInfoDetailModel, activityTeamProductSkuUpdModelList);
            activityTeamProductSkuInfoService.batchDel(subtract);
            //添加
            List<ActivityTeamSkuAddModel> activityTeamSkuAddModels=activityTeamProductSkuInfoService.activityTeamAdd(activityTeamInfoUpdModel.getId());
            List<ActivityTeamSkuAddModel> activityTeamSkuAddModelList = activityTeamSkuModel.getActivityTeamSkuAddModelList();
            Collection<ActivityTeamSkuAddModel> activityTeamSkuAddModelCollection = CollectionUtils.subtract(activityTeamSkuAddModelList, activityTeamSkuAddModels);
            activityTeamSkuAddModelCollection.forEach(activityTeamSkuAddModel -> {activityTeamSkuAddModel.setTeamId(activityTeamInfoUpdModel.getId());});
            activityTeamProductSkuInfoService.batchAdd(activityTeamSkuAddModelCollection);
            //修改
            activityTeamProductSkuInfoService.batchUpd(activityTeamSkuInfoDetailModel);
        }else {
            throw new ServiceException("拼团商品状态为活动中不可修改");
        }
    }
}
