package com.muyu.marketing.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuAddModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuEditModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuUpdModel;
import com.muyu.marketing.domain.model.ActivityTeamSkuAddModel;
import com.muyu.marketing.domain.req.ActivityTeamSkuReq;
import com.muyu.marketing.domain.resp.ActivityTeamSkuInfoDetail;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;
import java.util.List;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "activity_team_product_sku_info", autoResultMap = true)
public class ActivityTeamProductSkuInfo extends BaseEntity {

  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private long id;
  /**
   * 活动ID
   */
  private long teamId;
  /**
   * 商品ID
   */
  private Long productId;
  /**
   * 商品SKU
   */
  private String productSku;
  /**
   * 拼团库存
   */
  private Long teamStock;
  /**
   * 剩余库存
   */
  private Long remainStock;
  /**
   * 拼团价格
   */
  private BigDecimal teamPrice;

  /**
   * 通过模型钢构件对象
   * @param activityTeamProductSkuAddModel 模型
   * @return 对象
   */
  public static ActivityTeamProductSkuInfo modelBuild(ActivityTeamProductSkuAddModel activityTeamProductSkuAddModel) {
    return ActivityTeamProductSkuInfo.builder()
            .productId(activityTeamProductSkuAddModel.getProductId())
            .teamId(activityTeamProductSkuAddModel.getTeamId())
            .teamStock(activityTeamProductSkuAddModel.getTeamStock())
            .remainStock(activityTeamProductSkuAddModel.getTeamStock())
            .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
            .productSku(activityTeamProductSkuAddModel.getSku())
            .build();
  }
  /**
   * 将model模型转换成修改对象
   */
  public static ActivityTeamProductSkuInfo skuInfoBuild(ActivityTeamProductSkuEditModel activityTeamProductSkuEditModel){
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuEditModel.getId())
            .teamId(activityTeamProductSkuEditModel.getTeamId())
            .productSku(activityTeamProductSkuEditModel.getSku())
            .teamPrice(activityTeamProductSkuEditModel.getTeamPrice())
            .teamStock(activityTeamProductSkuEditModel.getTeamStock())
            .productId(activityTeamProductSkuEditModel.getProductId())
            .build();
  }
  public static ActivityTeamProductSkuInfo skuBuild(ActivityTeamProductSkuUpdModel activityTeamProductSkuUpdModel){
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuUpdModel.getId())
            .teamPrice(activityTeamProductSkuUpdModel.getTeamPrice())
            .remainStock(activityTeamProductSkuUpdModel.getTeamStock())
            .teamStock(activityTeamProductSkuUpdModel.getTeamStock())
            .build();
  }
  public static ActivityTeamProductSkuInfo skuBuildModel(ActivityTeamSkuAddModel activityTeamSkuAddModel){
    return ActivityTeamProductSkuInfo.builder()
            .productSku(activityTeamSkuAddModel.getSku())
            .teamPrice(activityTeamSkuAddModel.getTeamPrice())
            .remainStock(activityTeamSkuAddModel.getTeamStock())
            .teamStock(activityTeamSkuAddModel.getTeamStock())
            .productId(activityTeamSkuAddModel.getProductId())
            .teamId(activityTeamSkuAddModel.getTeamId())
            .build();
  }
  public static ActivityTeamProductSkuInfo skuModel(ActivityTeamProductSkuUpdModel activityTeamProductSkuUpdModel){
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuUpdModel.getId())
            .teamPrice(activityTeamProductSkuUpdModel.getTeamPrice())
            .remainStock(activityTeamProductSkuUpdModel.getTeamStock())
            .teamStock(activityTeamProductSkuUpdModel.getTeamStock())
            .build();
  }
}

