package com.muyu.marketing.team.controller;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.marketing.domain.model.ActivityTeamInfoListModel;
import com.muyu.marketing.domain.model.ActivityTeamInfoDetailModel;
import com.muyu.marketing.domain.req.ActivityTeamInfoEditReq;
import com.muyu.marketing.domain.req.ActivityTeamInfoSaveReq;
import com.muyu.marketing.domain.req.ActivityTeamInfoUpdReq;
import com.muyu.marketing.domain.req.TeamInfoListReq;
import com.muyu.marketing.domain.resp.ActivityTeamInfoProductSkuDetailResp;
import com.muyu.marketing.domain.resp.TeamInfoListResp;
import com.muyu.marketing.team.service.ActivityTeamInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 营销团购活动控制层
 *
 * @author DongZeLiang
 *  2024-11-20 14:25
 */
@RestController
@RequestMapping("/team")
public class ActivityTeamController {

    @Autowired
    private ActivityTeamInfoService activityTeamInfoService;

    /**
     * 查询营销团购活动列表
     * @param teamInfoListReq 活动查询入参
     * @return 活动响应结果
     */
    @PostMapping("/list")
    public Result<TableDataInfo<TeamInfoListResp>> list(@RequestBody TeamInfoListReq teamInfoListReq) {
        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = activityTeamInfoService.query(teamInfoListReq.buildQueryModel());
        List<TeamInfoListResp> respList = tableDataInfo.getRows().stream().map(TeamInfoListResp::listModelBuild).toList();
        return Result.success(
                new TableDataInfo<>(){{
                    setRows(respList);
                    setTotal(tableDataInfo.getTotal());
                }}
        );
    }
    /**
     * 添加团购活动
     */
    @PostMapping("/activityTeamInfoAdd")
    public void activityTeamInfoAdd(@RequestBody ActivityTeamInfoSaveReq activityTeamInfoSaveReq){
        activityTeamInfoService.save(activityTeamInfoSaveReq.activityTeamInfoReqBuild());
    }
    /**
     * 根据id查询拼团商品信息
     */
    @GetMapping("/inquireActivityTeam/{id}")
    public Result<ActivityTeamInfoProductSkuDetailResp> inquireActivityTeam(@PathVariable("id") Long id){
        ActivityTeamInfoDetailModel detailModel = activityTeamInfoService.echo(id);
        ActivityTeamInfoProductSkuDetailResp productSkuDetailBuild = ActivityTeamInfoProductSkuDetailResp.productSkuDetailBuild(detailModel);
        return Result.success(productSkuDetailBuild);
    }
    /**
     *修改团购活动
     */
    @PostMapping("/activityTeamEdit")
    public Result<String> activityTeamEdit(@RequestBody ActivityTeamInfoEditReq activityTeamInfoEditReq){
        activityTeamInfoService.edit(activityTeamInfoEditReq.activityTeamInfoEditBuild());
        return Result.success();
    }
    /**
     * 修改团购活动
     */
    @PostMapping("/upd")
    public Result<String> upd(@RequestBody ActivityTeamInfoUpdReq activityTeamInfoUpdReq){
        activityTeamInfoService.upd(activityTeamInfoUpdReq.infoUpdModelBuild());
        return Result.success();
    }
}
